adjust_for_non_move_closure

Function adjust_for_non_move_closure 

fn adjust_for_non_move_closure(
    place: Place,
    capture_info: &mut CaptureInfo,
) -> Place
Adjust closure capture just that if taking ownership of data, only move data from enclosing stack frame.