determine_place_ancestry_relation

Function determine_place_ancestry_relation 

fn determine_place_ancestry_relation(
    place_a: &Place,
    place_b: &Place,
) -> PlaceAncestryRelation
Determines the Ancestry relationship of Place A relative to Place B

PlaceAncestryRelation::Ancestor implies Place A is ancestor of Place B PlaceAncestryRelation::Descendant implies Place A is descendant of Place B PlaceAncestryRelation::Divergent implies neither of them is the ancestor of the other.