restrict_repr_packed_field_ref_capture

Function restrict_repr_packed_field_ref_capture 

fn restrict_repr_packed_field_ref_capture(
    place: Place,
    capture_info: &mut CaptureInfo,
) -> Place
Truncate the capture so that the place being borrowed is in accordance with RFC 1240, which states that it’s unsafe to take a reference into a struct marked repr(packed).