InferredCaptureInformation

Type Alias InferredCaptureInformation 

type InferredCaptureInformation = Vec<(Place, CaptureInfo)>;
Intermediate format to store a captured Place and associated CaptureInfo during capture analysis. Information in this map feeds into the minimum capture analysis pass.

Aliased Type

struct InferredCaptureInformation { /* private fields */ }