fn adjust_for_non_move_closure(
place: Place,
capture_info: &mut CaptureInfo,
) -> PlaceExpand description
Adjust closure capture just that if taking ownership of data, only move data from enclosing stack frame.
fn adjust_for_non_move_closure(
place: Place,
capture_info: &mut CaptureInfo,
) -> PlaceAdjust closure capture just that if taking ownership of data, only move data from enclosing stack frame.