struct InferBorrowKind {
closure_def_id: ExprId,
capture_information: Vec<(Place, CaptureInfo)>,
fake_reads: Vec<(Place, FakeReadCause, SmallVec<[CaptureSourceStack; 2]>)>,
}Fields
closure_def_id: ExprIdcapture_information: Vec<(Place, CaptureInfo)>For each Place that is captured by the closure, we track the minimal kind of access we need (ref, ref mut, move, etc) and the expression that resulted in such access.
Consider closure where s.str1 is captured via an ImmutableBorrow and s.str2 via a MutableBorrow
struct SomeStruct { str1: String, str2: String };
// Assume that the HirId for the variable definition is `V1`
let mut s = SomeStruct { str1: format!("s1"), str2: format!("s2") };
let fix_s = |new_s2| {
// Assume that the HirId for the expression `s.str1` is `E1`
println!("Updating SomeStruct with str1={0}", s.str1);
// Assume that the HirId for the expression `*s.str2` is `E2`
s.str2 = new_s2;
};For closure fix_s, (at a high level) the map contains
ⓘ
Place { V1, [ProjectionKind::Field(Index=0, Variant=0)] } : CaptureKind { E1, ImmutableBorrow }
Place { V1, [ProjectionKind::Field(Index=1, Variant=0)] } : CaptureKind { E2, MutableBorrow }fake_reads: Vec<(Place, FakeReadCause, SmallVec<[CaptureSourceStack; 2]>)>Trait Implementations
Sourceimpl<'db> Delegate<'db> for InferBorrowKind
impl<'db> Delegate<'db> for InferBorrowKind
Sourcefn fake_read(
&mut self,
place_with_id: PlaceWithOrigin,
cause: FakeReadCause,
ctx: &mut InferenceContext<'db>,
)
fn fake_read( &mut self, place_with_id: PlaceWithOrigin, cause: FakeReadCause, ctx: &mut InferenceContext<'db>, )
The
place should be a fake read because of specified cause.Sourcefn consume(
&mut self,
place_with_id: PlaceWithOrigin,
ctx: &mut InferenceContext<'db>,
)
fn consume( &mut self, place_with_id: PlaceWithOrigin, ctx: &mut InferenceContext<'db>, )
The value found at
place is moved, depending
on mode. Where diag_expr_id is the id used for diagnostics for place. Read moreSourcefn use_cloned(
&mut self,
place_with_id: PlaceWithOrigin,
ctx: &mut InferenceContext<'db>,
)
fn use_cloned( &mut self, place_with_id: PlaceWithOrigin, ctx: &mut InferenceContext<'db>, )
The value found at
place is used, depending
on mode. Where diag_expr_id is the id used for diagnostics for place. Read moreSourcefn borrow(
&mut self,
place_with_id: PlaceWithOrigin,
bk: BorrowKind,
ctx: &mut InferenceContext<'db>,
)
fn borrow( &mut self, place_with_id: PlaceWithOrigin, bk: BorrowKind, ctx: &mut InferenceContext<'db>, )
The value found at
place is being borrowed with kind bk.
diag_expr_id is the id used for diagnostics (see consume for more details).Sourcefn mutate(
&mut self,
assignee_place: PlaceWithOrigin,
ctx: &mut InferenceContext<'db>,
)
fn mutate( &mut self, assignee_place: PlaceWithOrigin, ctx: &mut InferenceContext<'db>, )
The path at
assignee_place is being assigned to.
diag_expr_id is the id used for diagnostics (see consume for more details).Sourcefn copy(
&mut self,
place_with_id: PlaceWithOrigin,
ctx: &mut InferenceContext<'db>,
)
fn copy( &mut self, place_with_id: PlaceWithOrigin, ctx: &mut InferenceContext<'db>, )
The value found at
place is being copied.
diag_expr_id is the id used for diagnostics (see consume for more details). Read moreSourcefn bind(
&mut self,
binding_place: PlaceWithOrigin,
ctx: &mut InferenceContext<'db>,
)
fn bind( &mut self, binding_place: PlaceWithOrigin, ctx: &mut InferenceContext<'db>, )
The path at
binding_place is a binding that is being initialized. Read moreAuto Trait Implementations
impl Freeze for InferBorrowKind
impl RefUnwindSafe for InferBorrowKind
impl Send for InferBorrowKind
impl Sync for InferBorrowKind
impl Unpin for InferBorrowKind
impl UnsafeUnpin for InferBorrowKind
impl UnwindSafe for InferBorrowKind